@@ -37,14 +37,13 @@ arguments.
 # TODO: Manage smart and configurable logs
 
 import daemon
-from daemon import pidlockfile
+import lockfile
 import logging
 import optparse
 import os
 import sys
 
 import calypso
-import calypso.config
 import calypso.webdav as webdav
 
 # Get command-line options
@@ -133,6 +132,9 @@ if options.import_dest:
 def run_server():
     try:
         # Launch server
+        log.debug("Starting HTTP%s server on %s:%d" % ("S" if options.ssl else "",
+                                                       options.host if options.host else "*",
+                                                       options.port))
         server_class = calypso.HTTPSServer if options.ssl else calypso.HTTPServer
         server = server_class(
             (options.host, options.port), calypso.CollectionHTTPHandler)
@@ -149,6 +151,7 @@ if not options.daemon:
 context = daemon.DaemonContext()
 context.umask = 0o002
 if options.pidfile:
+    from lockfile import pidlockfile
     # Generate a pidfile where requested
     context.pidfile = pidlockfile.PIDLockFile(options.pidfile)
 with context:
