@@ -61,7 +61,7 @@ formatter = logging.Formatter("%(message)s")
 ch.setFormatter (formatter)
 log.addHandler(ch)
 
-VERSION = "1.1"
+VERSION = "1.5"
 
 def _check(request, function):
     """Check if user has sufficient rights for performing ``request``."""
@@ -88,7 +88,7 @@ def _check(request, function):
         request.send_calypso_response(client.UNAUTHORIZED, 0)
         request.send_header(
             "WWW-Authenticate",
-            "Basic realm=\"Calypso Server - Password Required\"")
+            'Basic realm="Calypso CalDAV/CardDAV server - password required"')
         request.end_headers()
     # pylint: enable=W0212
 
@@ -137,7 +137,7 @@ class CollectionHTTPHandler(server.BaseHTTPRequestHandler):
 
     timeout = 90
 
-    server_version = "Calypso/1.0"
+    server_version = "Calypso/%s" % VERSION
 
     def address_string(self):
         return str(self.client_address[0])
@@ -341,6 +341,10 @@ class CollectionHTTPHandler(server.BaseHTTPRequestHandler):
                 self.send_header("Content-Type", "text/xml")
                 self.end_headers()
                 self.wfile.write(self._answer)
+            elif not item:
+                # Item does not exist
+                self.send_calypso_response(client.NOT_FOUND, 0)
+                self.end_headers()
             else:
                 # No item or ETag precondition not verified, do not delete item
                 self.send_calypso_response(client.PRECONDITION_FAILED, 0)
@@ -356,8 +360,7 @@ class CollectionHTTPHandler(server.BaseHTTPRequestHandler):
         self.send_calypso_response(client.CREATED, 0)
         self.end_headers()
 
-    @check_rights
-    def do_OPTIONS(self, context):
+    def do_OPTIONS(self):
         """Manage OPTIONS request."""
         self.send_calypso_response(client.OK, 0)
         self.send_header(
@@ -374,7 +377,8 @@ class CollectionHTTPHandler(server.BaseHTTPRequestHandler):
             log.debug("PROPFIND %s", xml_request)
             self._answer = xmlutils.propfind(
                 self.path, xml_request, self._collection,
-                self.headers.get("depth", "infinity"))
+                self.headers.get("depth", "infinity"),
+                context)
             log.debug("PROPFIND ANSWER %s", self._answer)
 
             self.send_calypso_response(client.MULTI_STATUS, len(self._answer))
@@ -411,12 +415,10 @@ class CollectionHTTPHandler(server.BaseHTTPRequestHandler):
                 # Case 2: Item and ETag precondition verified: Modify item
                 # Case 3: Item and no Etag precondition: Force modifying item
                 webdav_request = self._decode(self.xml_request)
-                xmlutils.put(self.path, webdav_request, self._collection, context=context)
+                new_item = xmlutils.put(self.path, webdav_request, self._collection, context=context)
                 
-                new_name = paths.resource_from_path(self.path)
-                log.debug("item_name %s new_name %s", item_name, new_name)
-                # We need to double get this item, because it just got created
-                etag = self._collection.get_item(new_name).etag
+                log.debug("item_name %s new_name %s", item_name, new_item.name)
+                etag = new_item.etag
                 #log.debug("replacement etag %s", etag)
 
                 self.send_calypso_response(client.CREATED, 0)
