@@ -29,16 +29,13 @@ Define the main classes of a collection as seen from the server.
 import os
 import codecs
 import time
-import calendar
 import hashlib
 import glob
 import logging
 import tempfile
 import vobject
-import string
 import re
 import subprocess
-import urllib
 
 from . import config, paths
 
@@ -115,6 +112,8 @@ class Item(object):
             return True
         if self.object.name == 'VEVENT':
             return False
+        if self.object.name == 'VCALENDAR':
+            return False
         for child in self.object.getChildren():
             if child.name == 'VCARD':
                 return True
@@ -124,11 +123,13 @@ class Item(object):
 
     @property
     def is_vcal(self):
-        """Whether this item is a vcard entry"""
+        """Whether this item is a vcal entry"""
         if self.object.name == 'VCARD':
             return False
         if self.object.name == 'VEVENT':
             return True
+        if self.object.name == 'VCALENDAR':
+            return True
         for child in self.object.getChildren():
             if child.name == 'VCARD':
                 return False
@@ -202,7 +203,7 @@ class Pathtime(object):
     """Path name and timestamps"""
 
     def __init__(self, path):
-    	self.path = path
+        self.path = path
         self.mtime = self.curmtime
 
     @property
@@ -227,6 +228,14 @@ class CalypsoError(Exception):
 class Collection(object):
     """Internal collection class."""
 
+    def get_description(self):
+        try:
+            f = codecs.open(os.path.join(self.path, ".git/description"), encoding='utf-8')
+        except IOError:
+            # .git/description is not present eg when the complete server is a single git repo
+            return self.urlpath
+        return f.read()
+
     def read_file(self, path):
         text = codecs.open(path,encoding='utf-8').read()
         item = Item(text, None, path)
@@ -274,9 +283,12 @@ class Collection(object):
                         self.scan_file(filename)
                     break
             else:
-                self.log.debug("New %s", filename)
-                newfiles.append(Pathtime(filename))
-                self.insert_file(filename)
+                if os.path.isdir(filename):
+                    self.log.debug("Ignoring directory %s in scan_dir", filename)
+                else:
+                    self.log.debug("New %s", filename)
+                    newfiles.append(Pathtime(filename))
+                    self.insert_file(filename)
         for file in self.files:
             if not file.path in filenames:
                 self.log.debug("Removed %s", file.path)
@@ -292,6 +304,7 @@ class Collection(object):
         
         self.log = logging.getLogger(__name__)
         self.encoding = "utf-8"
+        self.urlpath = path
         self.owner = paths.url_to_owner(path)
         self.path = paths.url_to_file(path)
         self.pattern = os.path.join(self.path, "*")
@@ -313,7 +326,7 @@ class Collection(object):
         return True
 
     def git_commit(self, context):
-        args = ["git", "commit"]
+        args = ["git", "commit", "--allow-empty"]
         env = {}
 
         message = context.get('action', 'other action')
@@ -384,7 +397,7 @@ class Collection(object):
             raise
         except Exception, ex:
             self.log.exception("Caught Exception")
-            self.log.debug("Failed to create %s: %s", path,  ex)
+            self.log.debug("Failed to create %s: %s", self.path,  ex)
             raise
 
     def destroy_file(self, item, context):
@@ -437,6 +450,7 @@ class Collection(object):
 
         """
 
+        self.log.debug('append name %s', name)
         try:
             new_item = Item(text, name, None)
         except Exception, e:
@@ -447,6 +461,7 @@ class Collection(object):
             raise CalypsoError(new_item.name, "Item already present")
         self.log.debug("New item %s", new_item.name)
         self.create_file(new_item, context=context)
+        return new_item
 
     def remove(self, name, context):
         """Remove object named ``name`` from collection."""
@@ -471,28 +486,49 @@ class Collection(object):
 
         ret = False
         if path is not None:
+            self.log.debug('rewrite path %s', path)
             self.rewrite_file(new_item, context=context)
         else:
+            self.log.debug('remove and append item %s', name)
             self.remove(name)
             self.append(name, text, context=context)
+        return new_item
+
+    def import_item(self, new_item, path):
+        old_item = self.get_item(new_item.name)
+        if old_item:
+            new_item.path = old_item.path
+            self.rewrite_file(new_item, context={})
+            self.log.debug("Updated %s from %s", new_item.name, path)
+        else:
+            self.create_file(new_item, context={})
+            self.log.debug("Added %s from %s", new_item.name, path)
 
     def import_file(self, path):
         """Merge items from ``path`` to collection.
         """
 
         try:
-            new_item = self.read_file(path)
-            old_item = self.get_item(new_item.name)
-            if old_item:
-                new_item.path = old_item.path
-                self.rewrite_file(new_item, context={})
-                self.log.debug("Updated %s from %s", new_item.name, path)
-            else:
-                self.create_file(new_item, context={})
-                self.log.debug("Added %s from %s", new_item.name, path)
+            new_object = vobject.readComponents(codecs.open(path,encoding='utf-8').read())
+            for new_ics in new_object:
+                if new_ics.name == 'VCALENDAR':
+
+                    events = new_ics.vevent_list
+                    for ve in events:
+                        # Check for events with both dtstart and duration entries and
+                        # delete the duration one
+                        if ve.contents.has_key('dtstart') and ve.contents.has_key('duration'):
+                            del ve.contents['duration']
+                        new_ics.vevent_list = [ve]
+                        new_item = Item(new_ics.serialize().decode('utf-8'), None, path)
+                        self.import_item(new_item, path)
+                else:
+                    new_item = Item(new_ics.serialize().decode('utf-8'), None, path)
+                    self.import_item(new_item, path)
+            return True
         except Exception, ex:
             self.log.exception("Failed to import: %s", path)
-            raise
+            return False
         
     def write(self, headers=None, items=None):
         return True
